@@ -136,7 +136,6 @@ class MultiStream(Stream):
     def __init__(self, ID="", flow=(), T=298.15, P=101325.,
                  phases=('g', 'l'), units=None,
                  thermo=None, price=0, **phase_flows):
-        self.path_priority = 0
         self._TP = ThermalCondition(T, P)
         thermo = self._load_thermo(thermo)
         self._init_indexer(flow, phases, thermo.chemicals, phase_flows)
@@ -177,6 +176,7 @@ class MultiStream(Stream):
             stream = streams[phase]
         else:
             stream = Stream.__new__(Stream)
+            stream._sink = stream._source = None
             stream._imol = self._imol.get_phase(phase)
             stream._ID = None
             stream._TP = self._TP
