@@ -202,8 +202,7 @@ class Stream:
     """
     __slots__ = ('_ID', '_imol', '_TP', '_thermo', '_streams',
                  '_bubble_point_cache', '_dew_point_cache',
-                 '_vle_cache', '_sink', '_source', '_price',
-                 'path_priority')
+                 '_vle_cache', '_sink', '_source', '_price')
     line = 'Stream'
     
     #: [DisplayUnits] Units of measure for IPython display (class attribute)
@@ -215,9 +214,6 @@ class Stream:
 
     def __init__(self, ID='', flow=(), phase='l', T=298.15, P=101325., units='kmol/hr',
                  price=0., thermo=None, **chemical_flows):
-        #: [bool] True if BioSTEAM should follow this stream's path first when 
-        # creating systems.
-        self.path_priority = 0
         self._TP = ThermalCondition(T, P)
         thermo = self._load_thermo(thermo)
         self._init_indexer(flow, phase, thermo.chemicals, chemical_flows)
@@ -931,7 +927,6 @@ class Stream:
         """
         cls = self.__class__
         new = cls.__new__(cls)
-        new.path_priority = 0
         new._sink = new._source = None
         new._thermo = self._thermo
         new._imol = self._imol.copy()
@@ -990,7 +985,6 @@ class Stream:
         new._dew_point_cache = self._dew_point_cache
         try: new._vle_cache = self._vle_cache
         except AttributeError: pass
-        new.path_priority = self.path_priority
         return new
     
     def empty(self):
